"use strict";
/* tslint:disable:max-classes-per-file */
Object.defineProperty(exports, "__esModule", { value: true });
var R = require('ramda');
var eslint_1 = require("./eslint");
var fs = require("fs");
var path = require("path");
var mkdirp = require("mkdirp");
var generateComponent = require("./react-content").generateComponent;
exports.baz = function () { return; };
var Formatter = /** @class */ (function () {
    function Formatter(project, ide) {
        this.ide = ide;
        var eslintDep = R.path(['dependencies', 'eslint'], project.pkgJson);
        var eslintDevDep = R.path(['devDependencies', 'eslint'], project.pkgJson);
        if (eslintDep || eslintDevDep) {
            this.linter = new eslint_1.Eslinter(project.projectRoot);
        }
    }
    Formatter.prototype.format = function (text, fileName) {
        try {
            return this.linter ?
                this.linter.format(text, fileName) :
                text;
        }
        catch (e) {
            this.ide.log("Failed to format output: " + e.message);
            return text;
        }
    };
    return Formatter;
}());
exports.Formatter = Formatter;
var FileSystem = /** @class */ (function () {
    function FileSystem() {
    }
    FileSystem.prototype.createComponent = function (component) {
        this.ensureFolderExists(component.folderPath);
        this.ensureFileExists(component.stylesPath);
        this.ensureFileExists(component.componentPath);
    };
    FileSystem.prototype.ensureFolderExists = function (pathToCheck) {
        var dirPath = path.extname(pathToCheck) ? path.dirname(pathToCheck) : pathToCheck;
        if (!fs.existsSync(dirPath)) {
            mkdirp.sync(dirPath);
        }
    };
    FileSystem.prototype.ensureFileExists = function (pathToCheck) {
        if (!fs.existsSync(pathToCheck)) {
            fs.closeSync(fs.openSync(pathToCheck, 'w'));
        }
    };
    return FileSystem;
}());
exports.FileSystem = FileSystem;
exports.fancyReactSettings = ["testStructure", "packagePath", "sourcePath", "testPath", "testSuffix"];
exports.generate = function (_a) {
    var fileSystem = _a.fileSystem, formatter = _a.formatter, ide = _a.ide, project = _a.project;
    var editor = ide.getEditor();
    var inputText = editor.getText();
    var cursorPosition = editor.getCursorPosition();
    var result = generateComponent(inputText, cursorPosition, project.sourcePath);
    result.matchWith({
        Error: function (_a) {
            var value = _a.value;
            return ide.log("Component generation failed: " + value);
        },
        Ok: function (_a) {
            var value = _a.value;
            var componentDetails = project.componentDetails(value.componentName);
            fileSystem.createComponent(componentDetails);
            if (value.changesToCaller) {
                value.changesToCaller.forEach(function (change, ix) {
                    // editor.setCursorScreenPosition(
                    //   { row: change.lineNumber + ix - 1, column: 0 });
                    // editor.insertNewline();
                    // editor.moveUp(1);
                    editor.insertText({ line: change.lineNumber + ix - 1, character: 0 }, change.content);
                    // editor.insertText(change.content);
                });
            }
            ide.open(componentDetails.componentPath).then(function (newEditor) {
                var formattedContent = formatter.format(value.content, componentDetails.componentPath);
                newEditor.setText(formattedContent);
            });
        },
    });
};
//# sourceMappingURL=index.js.map